# Workflows

This repository contains the main files to reproduce the work presented in "Building a consistent and reproducible database for adsorption evaluation in Covalent-Organic Frameworks".

## INSTALL

1) Install AiiDA v0.12.3 following the [instructions](https://aiida.readthedocs.io/projects/aiida-core/en/v0.12.3/installation/index.html)

2) The following packages are needed to run the calculations:

* [CP2K](https://www.cp2k.org/download)
* [Chargemol](https://sourceforge.net/projects/ddec/files/)
* [Raspa](https://github.com/iRASPA/RASPA2)
* [calc_pe](https://github.com/danieleongari/calc_pe)
 
3) The following python packages are needed to be installed in the AiiDA environment:

* [pandas](https://pandas.pydata.org/)
* [aiida-cp2k plugin](https://github.com/danieleongari/aiida-cp2k/tree/a39fe3a12a0d29615eab44cb5a11a4bcd11715fd)
* [aiida-ddec plugin](https://github.com/yakutovicha/aiida-ddec/tree/c9ad81ccd71097e70a741b5cf340bd354ff4e0f8)
* [aiida-raspa plugin](https://github.com/danieleongari/aiida-raspa/tree/b4eae47176c14dd5395929de2a81309d354c17ac)

4) Clone the repository with the CIF structures of the CURATED COFs from literature:
```
git clone https://github.com/danieleongari/CURATED-COFs
```

## USE

Run the python scripts as:
```
verdi run run_script.py 
``` 

In order:

1) `run1_cellopt.py` reads the list of COF IDs from `cof_ids.csv` together with the DFT settings to be used (OT or smearing), and looks for the respective CIF file in the `./CURATED-COFs/cifs/` directory. 
This script submit the `Cp2kCellOptDdecWorkChain`, which allows to perform the three-stages CELL optimization with CP2K and the evaluation of the DDEC charges from the electron density of the optimized struture.

2) `run2_VolpoKhIsotherm_CO2_N2.py` parse the optimized structures from the previous workflow and submit the `VolpoKhIsothermWorkChain` for both nitrogen and carbon dioxide. 
The `VolpoKhIsotherm` performs a preliminar Zeo++ calculation of the pore volume and blocking spheres, and only if the structure is found porous to the adsorbate (i.e., non-zero accessible pore volume) 
it follows with a Widom and a GCMC calculation at 300K. The file `UFF.rad` is used by Zeo++ as a list of radii for the frameworks' atoms. 

3) `run3_calcPE.py` parse the results from the CO2 and N2 `VolpoKhIsothermWorkChain` calculations and perform a `calc_pe` calculation to assess the performances of the CO2 separation process 
from coal post-combustion flue gasses.

See the manuscript for more details on the WorkChains.


