from aiida.common.example_helpers import test_and_get_code  # noqa
from aiida.orm.data.base import Float
from aiida.work.run import submit
from ase.io import read
from glob import glob
from os import path
import pandas as pd
from cellopt_charges import Cp2kCellOptDdecWorkChain
ParameterData = DataFactory('parameter')
StructureData = DataFactory('structure')

# Test the codes and specify the nodes and walltime
cp2k_code = test_and_get_code('cp2k@mycomputer', expected_code_type='cp2k')
ddec_code = test_and_get_code('ddec@mycomputer', expected_code_type='ddec')
cp2k_options = {
    "resources": {
        "num_machines": 2,
    },
    "max_wallclock_seconds": 72 * 60 * 60,
    }
ddec_options = {
    "resources": {
        "num_machines": 1,
    },
    "max_wallclock_seconds": 10 * 60 * 60,
    "withmpi": False,
    }

# Set the settings for CP2K
''' First CELL_OPT (Stage1), hardcoded
params_dict = {
        'MOTION':{
            'CELL_OPT': {
                'OPTIMIZER': 'BFGS',
                'MAX_ITER': 20,
                'KEEP_ANGLES' : True,
            },
        },
}
'''
params_ot_dict = {
    'MOTION': {
        'MD': {
            'ENSEMBLE': 'NPT_F',                    
            'STEPS': 100,                           
            'TIMESTEP': '[fs] 0.5',                 
            'TEMPERATURE': '[K] 400',               
            'DISPLACEMENT_TOL': '[angstrom] 1.0',   
            'THERMOSTAT' : {
                'REGION': 'GLOBAL',                 
                'TYPE': 'CSVR',
                'CSVR': {
                    'TIMECON': 0.1,                
                },
            },
            'BAROSTAT': {                           
                'PRESSURE': '[bar] 1.0',            
                'TIMECON': '[fs] 500',              
            },
        },
        'CELL_OPT': {
            'OPTIMIZER': 'LBFGS',                    
            'LBFGS' : {
                'TRUST_RADIUS': '[angstrom] 0.5',   
            },
            'MAX_ITER': 1000,
            'KEEP_ANGLES' : False,
        },
    },
}
params_smearing_dict = {
    'FORCE_EVAL': {
        'DFT': {
            'SCF': {
                'EPS_SCF': 1.0E-6,
                'MAX_SCF': 500,
                'MAX_ITER_LUMO': 10000,
                'ADDED_MOS': 1000,
                'SMEAR': {
                    '_': 'ON',
                    'METHOD': 'FERMI_DIRAC',
                    'ELECTRONIC_TEMPERATURE': '[K] 300',
                    },
                'DIAGONALIZATION': {
                    '_': True,
                    'ALGORITHM': 'STANDARD'
                    },
                'OT': {
                    '_': False,
                    },
                'OUTER_SCF': {
                    '_': False,
                    },
                'MIXING': {
                    '_': True,
                    'METHOD': 'BROYDEN_MIXING',
                    'ALPHA': 0.4,
                    'NBROYDEN': 8,
                    },
                },
            },
        },
    'MOTION': {
        'MD': {
            'ENSEMBLE': 'NPT_F',                    
            'STEPS': 100,                           
            'TIMESTEP': '[fs] 0.5',                 
            'TEMPERATURE': '[K] 400',               
            'DISPLACEMENT_TOL': '[angstrom] 1.0',   
            'THERMOSTAT' : {
                'REGION': 'GLOBAL',                
                'TYPE': 'CSVR',
                'CSVR': {
                    'TIMECON': 0.1,                
                },
            },
            'BAROSTAT': {                           
                'PRESSURE': '[bar] 1.0',            
                'TIMECON': '[fs] 500',              
            },
        },
        'CELL_OPT': {
            'OPTIMIZER': 'LBFGS',                    
            'LBFGS' : {
                'TRUST_RADIUS': '[angstrom] 0.5',    
            },
            'MAX_ITER': 1000,
            'KEEP_ANGLES' : False,
        },
    },
}

# Read labels from list
df=pd.read_csv("cof_ids.csv")

# Submit the calculation for each structure
for i in df.index:
    structure_ase = read("./CURATED-COFs/cifs/{}.cif".format(df.at[i,'cof_label']))
    structure = StructureData(ase=structure_ase)
    structure.label = structure_label
    structure.store()
    if df.at[i,'cellopt_label'] == 'cellopt-ot':
	params_dict = params_ot_dict
    elif df.at[i,'cellopt_label'] == 'cellopt-smearing':
	params_dict = params_smearing_dict 
    submit(Cp2kCellOptDdecWorkChain,
        structure = structure,
        cp2k_code = cp2k_code,
        cp2k_parameters = ParameterData(dict=params_dict),
        _cp2k_options = cp2k_options,
        ddec_code = ddec_code,
        _ddec_options = ddec_options,
        _label = df.at[i,'cellopt_label'],
        _guess_multiplicity=True,
        min_cell_size=Float(5.0)
        )
